ImageView class

Inheritance

Constructors

ImageView({Key? key, bool? ignoreFullView, VoidCallback? onTap, BuildContext? context, required Uri uri, Widget aboveBuilder(MediaView index)?, BoxFit fit = BoxFit.contain, double? aspectRatio, double? width, double? height, Color? color, bool cache = true, Decoration? decoration, Clip? clipBehavior, EdgeInsets? margin, EdgeInsets? padding, Widget errorBuilder(BuildContext, Object)?, Widget loadingBuilder(BuildContext, ImageChunkEvent?)?})

Properties

aboveBuilder Widget Function(MediaView index)?
finalinherited
aspectRatio double?
final
cache bool
final
child Widget
no setteroverride
clipBehavior Clip?
final
color Color?
final
context BuildContext?
finalinherited
decoration Decoration?
final
errorBuilder Widget Function(BuildContext, Object)?
final
fit BoxFit
final
fullView Widget
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
height double?
final
ignoreFullView bool
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder Widget Function(BuildContext, ImageChunkEvent?)?
final
margin EdgeInsets?
final
onTap VoidCallback?
finalinherited
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPressed(BuildContext context) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited